@@ -63,13 +63,13 @@ class GitLibMixin:
         return self.__repo.head.raw_name
 
     def loadGitRepo(self):
-        self.__repo = pygit2.Repository(self._repoPath)
+        self.__repo = pygit2.Repository(self._repoPath.as_posix())
         if self.__repo.is_bare:
             raise ValueError(f"{self._repoPath} points to a Git Bare Repo")
 
     def initGitRepo(self):
         # Create target repo
-        self.__repo = pygit2.init_repository(self._repoPath)
+        self.__repo = pygit2.init_repository(self._repoPath.as_posix())
         self.__indexInitialised = True
         logger.info(f"Create Git repository at {self._repoPath}")
         self.__createInitialCommit()
@@ -110,7 +110,7 @@ class GitLibMixin:
     @classmethod
     def cloneGitRepo(
         cls,
-        projectPath: str,
+        projectPath: Path,
         url: str,
         username: str = None,
         password: str = None,
@@ -124,7 +124,7 @@ class GitLibMixin:
 
         pygit2.clone_repository(
             url,
-            str(projectPath),
+            projectPath.as_posix(),
             bare=False,
             callbacks=RemoteCallbacks(credentials=cred),
         )
@@ -162,9 +162,9 @@ class GitLibMixin:
                     item, pygit2.Object
                 ), "item is not a pygit2.Object"
                 self.__index.add(
-                    pygit2.IndexEntry(toItemPath, item.oid, item.filemode)
+                    pygit2.IndexEntry(toItemPath.as_posix(), item.oid, item.filemode)
                 )
-                self.__index.remove(fromItemPath)
+                self.__index.remove(fromItemPath.as_posix())
 
         recurse(fromPath, toPath, fromTree)
         self.__isIndexDirty = True
@@ -180,8 +180,8 @@ class GitLibMixin:
         blob = fromTree / fromPath.name
         assert isinstance(blob, pygit2.Object), "blob is not a pygit2.Object"
 
-        self.__index.add(pygit2.IndexEntry(toPath, blob.oid, blob.filemode))
-        self.__index.remove(fromPath)
+        self.__index.add(pygit2.IndexEntry(toPath.as_posix(), blob.oid, blob.filemode))
+        self.__index.remove(fromPath.as_posix())
         self.__isIndexDirty = True
 
     def _deleteDirectory(self, path: Path):
@@ -205,7 +205,7 @@ class GitLibMixin:
                 assert isinstance(
                     item, pygit2.Object
                 ), "item is not a pygit2.Object"
-                self.__index.remove(itemPath)
+                self.__index.remove(itemPath.as_posix())
 
         recurse(path, startTree)
         self.__isIndexDirty = True
@@ -217,7 +217,7 @@ class GitLibMixin:
         blob = tree / path.name
         assert isinstance(blob, pygit2.Object), "blob is not a pygit2.Object"
 
-        self.__index.remove(path)
+        self.__index.remove(path.as_posix())
         self.__isIndexDirty = True
 
     def _readFile(self, path: Path) -> bytes:
@@ -319,7 +319,7 @@ class GitLibMixin:
         # We will read objects as they are at the working branch
         tree = self.__workingTree
         climbedPath = ""
-        for pathComponent in str(path).split("/"):
+        for pathComponent in path.as_posix().split("/"):
             climbedPath += f"/{pathComponent}"
             if pathComponent in tree:
                 tree = tree / pathComponent
